<template>
  <el-dialog :visible.sync="visible" append-to-body :title="!dataForm.id ? $t('add') : $t('update')"
             :close-on-click-modal="false" :close-on-press-escape="false">
    <el-form :model="dataForm" :rules="dataRule" ref="dataForm" label-width="110px">
      <el-row>
        <el-col :span="12">
          <el-form-item prop="rq" label="日期">
            <el-date-picker
                style="width: 100%"
                v-model="dataForm.rq"
                type="date"
                :clearable="true"
                value-format="yyyy-MM-dd"
                placeholder="日期">
            </el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item prop="bc" label="班次">
            <dict-select-tag style="width: 100%" v-model="dataForm.bc" clearable placeholder="班次" dictCode="bc"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item prop="mc" label="煤仓">
            <dict-select-tag style="width: 100%" v-model="dataForm.mc" clearable placeholder="煤仓" dictCode="cpc"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item prop="cp" label="产品">
            <dict-select-tag style="width: 100%" v-model="dataForm.cp" clearable placeholder="产品" dictCode="cpmz"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item prop="nbgl" label="内报估量">
            <el-input-number style="width: 100%" v-model="dataForm.nbgl" :precision="0" :step="1" :min="0"></el-input-number>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item prop="wbgl" label="外报估量">
            <el-input-number style="width: 100%" v-model="dataForm.wbgl" :precision="0" :step="1" :min="0"></el-input-number>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item prop="bz" label="备注">
            <el-input
                type="textarea"
                :autosize="{ minRows: 6, maxRows: 6}"
                placeholder="请输入备注"
                v-model="dataForm.bz">
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template slot="footer">
      <el-button size="mini" :loading="loading" @click="visible = false">{{ $t('cancel') }}</el-button>
      <el-button size="mini" :loading="loading" type="primary" @click="dataFormSubmitHandle()">{{ $t('confirm') }}
      </el-button>
    </template>
  </el-dialog>
</template>

<script>
import debounce from 'lodash/debounce'
import DictSelectTag from '@/components/dict/dict-select-tag'
import {getDictItem} from "@/utils/dictUtils";
export default {
  data() {
    return {
      visible: false,
      loading: false,
      dataForm: {
        id: '',
        rq: '',
        bc: '',
        mc: '',
        crl: '',
        cp: '',
        nbgl: '',
        wbgl: '',
        bz: ''
      }
    }
  },
  components: {
    DictSelectTag
  },
  computed: {
    dataRule() {
      return {
        rq: [
          {required: true, message: this.$t('validate.required'), trigger: 'blur'}
        ],
        bc: [
          {required: true, message: this.$t('validate.required'), trigger: 'blur'}
        ],
        mc: [
          {required: true, message: this.$t('validate.required'), trigger: 'blur'}
        ],
        cp: [
          {required: true, message: this.$t('validate.required'), trigger: 'blur'}
        ],
        nbgl: [
          {required: true, message: this.$t('validate.required'), trigger: 'blur'}
        ],
        wbgl: [
          {required: true, message: this.$t('validate.required'), trigger: 'blur'}
        ]
      }
    }
  },
  methods: {
    init() {
      this.visible = true
      this.$nextTick(() => {
        this.$refs['dataForm'].resetFields()
        if (this.dataForm.id) {
          this.getInfo()
        }
      })
    },
    // 获取信息
    getInfo() {
      this.$http.get(`/iailab-iems-coal-proddisp/warehouse/position/info/${this.dataForm.id}`).then(({data: res}) => {
        if (res.code !== 0) {
          return this.$message.error(res.msg)
        }
        this.dataForm = {
          ...this.dataForm,
          ...res.info
        }
      }).catch(() => {
      })
    },
    // 表单提交
    dataFormSubmitHandle: debounce(function () {
      this.$refs['dataForm'].validate((valid) => {
        if (!valid) {
          return false
        }
        this.loading = true
        this.dataForm.crl = getDictItem('cpc', this.dataForm.mc).ext2
        this.$http['post'](`/iailab-iems-coal-proddisp/warehouse/position/${!this.dataForm.id ? 'add' : 'update'}`, this.dataForm).then(({data: res}) => {
          this.loading = false
          if (res.code !== 0) {
            return this.$message.error(res.msg)
          }
          this.$message({
            message: this.$t('prompt.success'),
            type: 'success',
            duration: 500,
            onClose: () => {
              this.visible = false
              this.$emit('refreshDataList')
            }
          })
        }).catch(() => {
        })
      })
    }, 1000, {'leading': true, 'trailing': false})
  }
}
</script>
